%define anolis_release 4

Name:           brotli
Version:        1.0.9
Release:        %{anolis_release}%{?dist}
Summary:        Lossless compression algorithm

License:        MIT
URL:            https://github.com/google/brotli
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         brotli-1.0.9-drop-rapth-from-pc-files.patch

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  python3-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
Requires: lib%{name} = %{version}-%{release}

%description
Brotli is a generic-purpose lossless compression algorithm that compresses
data using a combination of a modern variant of the LZ77 algorithm, Huffman
coding and 2nd order context modeling, with a compression ratio comparable
to the best currently available general-purpose compression methods.
It is similar in speed with deflate but offers more dense compression.

%package -n libbrotli
Summary:        Library for brotli lossless compression algorithm

%description -n libbrotli
Brotli is a generic-purpose lossless compression algorithm that compresses
data using a combination of a modern variant of the LZ77 algorithm, Huffman
coding and 2nd order context modeling, with a compression ratio comparable
to the best currently available general-purpose compression methods.
It is similar in speed with deflate but offers more dense compression.


%package -n python%{python3_pkgversion}-%{name}
Summary:        Lossless compression algorithm (python 3)
%{?python_provide:%python_provide python%{python3_pkgversion}-%{name}}

%description -n python%{python3_pkgversion}-%{name}
Brotli is a generic-purpose lossless compression algorithm that compresses
data using a combination of a modern variant of the LZ77 algorithm, Huffman
coding and 2nd order context modeling, with a compression ratio comparable
to the best currently available general-purpose compression methods.
It is similar in speed with deflate but offers more dense compression.
This package installs a Python 3 module.


%package devel
Summary:        Lossless compression algorithm (development files)
Requires: %{name} = %{version}-%{release}
Requires: lib%{name} = %{version}-%{release}

%description devel
Brotli is a generic-purpose lossless compression algorithm that compresses
data using a combination of a modern variant of the LZ77 algorithm, Huffman
coding and 2nd order context modeling, with a compression ratio comparable
to the best currently available general-purpose compression methods.
It is similar in speed with deflate but offers more dense compression.
This package installs the development files

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -p1
# fix permissions for -debuginfo
# rpmlint will complain if I create an extra %%files section for
# -debuginfo for this so we'll put it here instead
chmod 644 c/enc/*.[ch]
chmod 644 c/include/brotli/*.h
chmod 644 c/tools/brotli.c

%build
%cmake \
    -DCMAKE_INSTALL_PREFIX="%{_prefix}" \
    -DCMAKE_INSTALL_LIBDIR="%{_libdir}"
%cmake_build
%py3_build

%install
%cmake_install

# I couldn't find the option to not build the static libraries
rm "%{buildroot}%{_libdir}/"*.a

%py3_install
install -dm755 "%{buildroot}%{_mandir}/man3"
cd docs
for i in *.3;do
install -m644 "$i" "%{buildroot}%{_mandir}/man3/${i}brotli"
done

%generate_compatibility_deps

%check
%ctest

%files
%{_bindir}/brotli
%{abidir}/brotli-option.list

%files -n libbrotli
%dir %{abidir}
%{_libdir}/libbrotlicommon.so.1*
%{_libdir}/libbrotlidec.so.1*
%{_libdir}/libbrotlienc.so.1*
%{abidir}/libbrotlicommon.dump
%{abidir}/libbrotlidec.dump
%{abidir}/libbrotlienc.dump
%license LICENSE

# Note that there is no %%files section for the unversioned python module
# if we are building for several python runtimes
%files -n python%{python3_pkgversion}-%{name}
%{python3_sitearch}/brotli.py
%{python3_sitearch}/_brotli.cpython-%{python3_version_nodots}*.so
%{python3_sitearch}/__pycache__/brotli.cpython-%{python3_version_nodots}*.py*
%{python3_sitearch}/Brotli-%{version}-py%{python3_version}.egg-info
%{abidir}/_brotli.cpython-310-%{_arch}-linux-gnu.dump
%license LICENSE

%files devel
%{_includedir}/brotli
%{_libdir}/libbrotlicommon.so
%{_libdir}/libbrotlidec.so
%{_libdir}/libbrotlienc.so
%{_libdir}/pkgconfig/libbrotlicommon.pc
%{_libdir}/pkgconfig/libbrotlidec.pc
%{_libdir}/pkgconfig/libbrotlienc.pc
%{_mandir}/man3/constants.h.3brotli*
%{_mandir}/man3/decode.h.3brotli*
%{_mandir}/man3/encode.h.3brotli*
%{_mandir}/man3/types.h.3brotli*

%files doc
%doc README

%changelog
* Mon Jan 09 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.0.9-4
- Add doc package

* Tue Nov 01 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.0.9-3
- optimise spec file

* Wed Oct 12 2022 <fundawang@yeah.net> - 1.0.9-2
- Add upstream patch to Revert "Add runtime linker path to pkg-config files"

* Tue Mar 08 2022 pangqing <pangqing@uniontech.com> - 1.0.9-1
- Init for anolisOS 23

